@@ -1,7 +1,7 @@
 package App::cryp::arbit;
 
 our $DATE = '2018-11-29'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -600,9 +600,12 @@ sub _get_exchange_client {
             "Please specify [exchange/$exchange/$account] section in configuration";
     }
 
-    my $client = $mod->new(
-        %{ $r->{_cryp}{exchanges}{$exchange}{$account} }
-    );
+    my %client_args = %{ $r->{_cryp}{exchanges}{$exchange}{$account} // {} };
+    unless ($client_args{api_key}) {
+        $client_args{public_only} = 1;
+    }
+
+    my $client = $mod->new(%client_args);
 
     $r->{_stash}{exchange_clients}{$exchange}{$account} = $client;
 }
@@ -1892,7 +1895,7 @@ App::cryp::arbit - Cryptocurrency arbitrage utility
 
 =head1 VERSION
 
-This document describes version 0.007 of App::cryp::arbit (from Perl distribution App-cryp-arbit), released on 2018-11-29.
+This document describes version 0.008 of App::cryp::arbit (from Perl distribution App-cryp-arbit), released on 2018-11-29.
 
 =head1 SYNOPSIS
 
